@@ -49,6 +49,10 @@ def compile_Kernels(thr):
     program = thr.compile(open(path/"GPU_Kernels/Slice.cl").read())
     GPU.Slice = program.Slice
 
+    # Initialize u_index_1 and v_index_1
+    program = thr.compile(open(path/"GPU_Kernels/ini_index.cl").read())
+    GPU.ini_index = program.ini_index
+
     # Normalize image Kernel
     program = thr.compile(open(path/"GPU_Kernels/SubMean.cl").read())
     GPU.SubMean = program.SubMean
@@ -102,8 +106,14 @@ def compile_Kernels(thr):
     program = thr.compile(open(path/"GPU_Kernels/Weighting.cl").read())
     GPU.Weighting = program.Weighting
 
+    # Gaussian blur
+    program = thr.compile(open(path/"GPU_Kernels/gaussian_filter.cl").read())
+    GPU.gaussian_filter = program.gaussian_filter
+
     thr.synchronize()
 
+    return 0
+
 def initialization(width, height, thr):
     """
     Initialize variables in GPU memory
@@ -117,25 +127,12 @@ def initialization(width, height, thr):
     N_boxes_1 = Parameters.no_boxes_1_x*Parameters.no_boxes_1_y
     N_boxes_2 = Parameters.no_boxes_2_x*Parameters.no_boxes_2_y
 
-    # Initialice velocity vectors solution fot first step
-    u1 = np.zeros([Parameters.no_boxes_1_y,
-        Parameters.no_boxes_1_x]).astype(np.float32)
-    v1 = np.zeros([Parameters.no_boxes_1_y,
-        Parameters.no_boxes_1_x]).astype(np.float32)
-
-    # Initialize Subimage matrix
+    # subImg examples to compile fft kernel
     subImg1 = np.zeros((N_boxes_1, Parameters.box_size_1_y,
         Parameters.box_size_1_x), dtype = np.complex64)
     subImg2 = np.zeros((N_boxes_2, Parameters.box_size_2_y,
         Parameters.box_size_2_x), dtype = np.complex64)
-    frac1 = np.zeros((N_boxes_1, Parameters.box_size_1_y,
-        Parameters.box_size_1_x), dtype = np.float32)
-    frac = np.zeros((N_boxes_2, Parameters.box_size_2_y,
-        Parameters.box_size_2_x), dtype = np.float32)
-    subMean1 = np.zeros((Parameters.no_boxes_1_y, Parameters.no_boxes_1_x),
-        dtype = np.float32)
-    subMean2 = np.zeros((Parameters.no_boxes_2_y, Parameters.no_boxes_2_x),
-        dtype = np.float32)
+
 
     # Array of parameters data
     peak_ratio = int(Parameters.peak_ratio*1000)  #trick pass this value as int
@@ -144,24 +141,12 @@ def initialization(width, height, thr):
         Parameters.box_size_1_x, Parameters.box_size_1_y,
         Parameters.no_boxes_1_x, Parameters.no_boxes_1_y,
         Parameters.window_x_1, Parameters.window_y_1,
-        peak_ratio)).astype(np.int32)
+        peak_ratio, Parameters.gaussian_filter)).astype(np.int32)
     data2 = np.array((width, height,
         Parameters.box_size_2_x, Parameters.box_size_2_y,
         Parameters.no_boxes_2_x, Parameters.no_boxes_2_y,
         Parameters.window_x_2, Parameters.window_y_2,
-        peak_ratio)).astype(np.int32)
-
-    # Initialice velocity vectors solution fot first step
-    u1 = np.zeros([Parameters.no_boxes_1_y,
-        Parameters.no_boxes_1_x]).astype(np.float32)
-    v1 = np.zeros([Parameters.no_boxes_1_y,
-        Parameters.no_boxes_1_x]).astype(np.float32)
-
-    # Initialice velocity vectors solution for second step
-    u2 = np.zeros([Parameters.no_boxes_2_y,
-        Parameters.no_boxes_2_x]).astype(np.float32)
-    v2 = np.zeros([Parameters.no_boxes_2_y,
-        Parameters.no_boxes_2_x]).astype(np.float32)
+        peak_ratio, Parameters.gaussian_filter)).astype(np.int32)
 
     # Send mesh to gpu (only done once)
     GPU.box_origin_x_1 = thr.to_device(grid.box_origin_x_1)
@@ -179,79 +164,210 @@ def initialization(width, height, thr):
     GPU.data2 = thr.to_device(data2)
     GPU.median_limit = thr.to_device(np.float32(Parameters.median_limit))
 
-
-    # Initialice all intermediate variables on gpu (only done one)
-    GPU.subImg1_1 = thr.empty_like(subImg1)
-    GPU.subImg1_2 = thr.empty_like(subImg1)
-
-    GPU.subImg2_1 = thr.empty_like(subImg2)
-    GPU.subImg2_2 = thr.empty_like(subImg2)
-
-    """
-    #Subimages complety managed with temp_manager to save memory.
-    #Currently is not working due to Reikna Package bug. If you are
-    #interested on using it, clone and install the tempalloc-fix
-    #branch of Reikna package in git. This fix is not yet upload to pypi.
-    #For using the temp_manager, delete or comment the previous
-    #initialization of GPU images and uncomment this implementation
-
     #Temp manager
     temp_manager = ZeroOffsetManager(
-            thr, pack_on_alloc=True, pack_on_free=True)
+            thr, pack_on_alloc=True, pack_on_free=False)
 
+    # Initialice all GPU variables for first iteration (only done once)
     GPU.subImg1_1 = temp_manager.array([N_boxes_1,
         Parameters.box_size_1_y, Parameters.box_size_1_x],
         np.complex64)
+
     GPU.subImg1_2 = temp_manager.array([N_boxes_1,
         Parameters.box_size_1_y, Parameters.box_size_1_x],
         np.complex64, dependencies = [GPU.subImg1_1])
 
+    GPU.subMean1_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2])
+
+    GPU.subMean1_2 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1])
+
+    GPU.u1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2])
+
+    GPU.v1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1])
+
+    GPU.u1_f = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1])
+
+    GPU.v1_f = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f])
+
+    GPU.du_dx_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f])
+
+    GPU.du_dy_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f, GPU.du_dx_1])
+
+    GPU.dv_dx_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f, GPU.du_dx_1, GPU.du_dy_1])
+
+    GPU.dv_dy_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f, GPU.du_dx_1, GPU.du_dy_1, GPU.dv_dx_1])
+
+    GPU.temp_dx_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f, GPU.du_dx_1, GPU.du_dy_1, GPU.dv_dx_1,
+        GPU.dv_dy_1])
+
+    GPU.temp_dy_1 = temp_manager.array(
+        [Parameters.no_boxes_1_y, Parameters.no_boxes_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1, GPU.u1_f,
+        GPU.v1_f, GPU.du_dx_1, GPU.du_dy_1, GPU.dv_dx_1,
+        GPU.dv_dy_1, GPU.temp_dx_1])
+
+    GPU.u_index_1 = temp_manager.array([N_boxes_1,
+        Parameters.box_size_1_y, Parameters.box_size_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1,
+        GPU.du_dx_1, GPU.du_dy_1, GPU.dv_dx_1,
+        GPU.dv_dy_1, GPU.temp_dx_1, GPU.temp_dy_1])
+
+    GPU.v_index_1 = temp_manager.array([N_boxes_1,
+        Parameters.box_size_1_y, Parameters.box_size_1_x],
+        np.float32, dependencies = [GPU.subImg1_1, GPU.subImg1_2,
+        GPU.subMean1_1, GPU.subMean1_2, GPU.u1, GPU.v1,
+        GPU.du_dx_1, GPU.du_dy_1, GPU.dv_dx_1,
+        GPU.dv_dy_1, GPU.temp_dx_1, GPU.temp_dy_1,
+        GPU.u_index_1])
+
+    #Create temp images for gaussian filter if needed
+    if (Parameters.gaussian_filter):
+
+        kernel = DPIV.gaussian_kernel(Parameters.gaussian_filter)
+        GPU.kernel = thr.to_device(np.float32(kernel))
+
+        # Images filtered to be used only on first iteration
+        GPU.img1_g = temp_manager.array([height, width],
+            np.float32, dependencies = [GPU.subImg1_1,
+            GPU.subImg1_2])
+        GPU.img2_g = temp_manager.array([height, width],
+            np.float32, dependencies = [GPU.subImg1_1,
+            GPU.subImg1_2, GPU.img1_g])
+
+    # Initialice all GPU variables for second iteration (only done once)
     GPU.subImg2_1 = temp_manager.array([N_boxes_2,
         Parameters.box_size_2_y, Parameters.box_size_2_x],
         np.complex64)
+
     GPU.subImg2_2 = temp_manager.array([N_boxes_2,
         Parameters.box_size_2_y, Parameters.box_size_2_x],
         np.complex64, dependencies = [GPU.subImg2_1])
-    """
 
-    GPU.u_index_1 = thr.to_device(frac1)
-    GPU.v_index_1 = thr.to_device(frac1)
-    GPU.u_index_2 = thr.to_device(frac)
-    GPU.v_index_2 = thr.to_device(frac)
+    GPU.subMean2_1 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2])
 
-    GPU.subMean1_1 = thr.to_device(subMean1)
-    GPU.subMean1_2 = thr.to_device(subMean1)
-    GPU.subMean2_1 = thr.to_device(subMean2)
-    GPU.subMean2_2 = thr.to_device(subMean2)
+    GPU.subMean2_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1])
 
-    GPU.u1 = thr.empty_like(u1)
-    GPU.v1 = thr.empty_like(v1)
-    GPU.u1_f = thr.empty_like(u1)
-    GPU.v1_f = thr.empty_like(v1)
-    GPU.u2 = thr.empty_like(u2)
-    GPU.v2 = thr.empty_like(u2)
-    GPU.u2_f = thr.empty_like(u2)
-    GPU.v2_f = thr.empty_like(u2)
+    GPU.u2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2])
 
-    GPU.du_dx_1 = thr.empty_like(u1)
-    GPU.du_dy_1 = thr.empty_like(u1)
-    GPU.dv_dx_1 = thr.empty_like(u1)
-    GPU.dv_dy_1 = thr.empty_like(u1)
-    GPU.temp_dx = thr.empty_like(u1)
-    GPU.temp_dy = thr.empty_like(u1)
-    GPU.temp_dx_2 = thr.empty_like(u2)
-    GPU.temp_dy_2 = thr.empty_like(u2)
+    GPU.v2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2])
+
+    GPU.u2_f = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2, GPU.u1])
+
+    GPU.v2_f = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2, GPU.u2_f, GPU.v1])
+
+    GPU.du_dx_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2])
+
+    GPU.du_dy_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2, GPU.du_dx_2])
+
+    GPU.dv_dx_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2])
+
+    GPU.dv_dy_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2, GPU.dv_dx_2])
+
+    GPU.temp_dx_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2, GPU.dv_dx_2,
+        GPU.dv_dy_2])
+
+    GPU.temp_dy_2 = temp_manager.array(
+        [Parameters.no_boxes_2_y, Parameters.no_boxes_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2, GPU.dv_dx_2,
+        GPU.dv_dy_2, GPU.temp_dx_2])
+
+    GPU.u_index_2 = temp_manager.array([N_boxes_2,
+        Parameters.box_size_2_y, Parameters.box_size_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2, GPU.dv_dx_2,
+        GPU.dv_dy_2, GPU.temp_dx_2, GPU.temp_dy_2])
+
+    GPU.v_index_2 = temp_manager.array([N_boxes_2,
+        Parameters.box_size_2_y, Parameters.box_size_2_x],
+        np.float32, dependencies = [GPU.subImg2_1, GPU.subImg2_2,
+        GPU.subMean2_1, GPU.subMean2_2, GPU.u2, GPU.v2,
+        GPU.du_dx_2, GPU.du_dy_2, GPU.dv_dx_2,
+        GPU.dv_dy_2, GPU.temp_dx_2, GPU.temp_dy_2,
+        GPU.u_index_2])
 
-    GPU.du_dx_2 = thr.empty_like(u2)
-    GPU.du_dy_2 = thr.empty_like(u2)
-    GPU.dv_dx_2 = thr.empty_like(u2)
-    GPU.dv_dy_2 = thr.empty_like(u2)
 
     # Load mask if any
     if Parameters.mask:
         GPU.mask = thr.to_device(Parameters.Data.mask)
     else:
-        temp = np.zeros(2);
+        temp = np.zeros(2)
         GPU.mask = thr.empty_like(temp)
 
     # Initialize GPU computations for the cross-correlation
@@ -262,6 +378,8 @@ def initialization(width, height, thr):
     GPU.fft2 = FFT(subImg2, axes=GPU.axes).compile(thr)
     GPU.fftshift2 = FFTShift(subImg2, axes=GPU.axes).compile(thr)
 
+    return 0
+
 
 def processing(img1_name, img2_name, thr):
     """
@@ -272,11 +390,13 @@ def processing(img1_name, img2_name, thr):
 
     Inputs:
     -------
-    Img1: 2d array of simple float
-        Image from a flow field with trazers particles inside it.
+    Img1_name: str
+        Path to the first Image of the next iteration to be loaded
+        asynchronously during runtime
 
-    Img2: 2d array of simple float
-        Image consecutive to Img1.
+    Img2_name: str
+        Path to the second Image of the next iteration to be loaded
+        asynchronously during runtime
 
     thr: openCL object
         Platform where to perform the operations in openCL.
@@ -323,24 +443,38 @@ def processing(img1_name, img2_name, thr):
     N_pixels_1 = N_boxes_1*Parameters.box_size_1_x*Parameters.box_size_1_y
     N_pixels_2 = N_boxes_2*Parameters.box_size_2_x*Parameters.box_size_2_y
 
-    # Image Gaussian filter if required
-    if Parameters.gaussian_filter:
-        # Reserved to implement the filter
-        pass
+    #Set to zero the required variables
+    GPU.ini_index(GPU.u_index_1, GPU.v_index_2, local_size = None,
+            global_size = N_pixels_1)
+
 
     # Mask images if required
     if Parameters.mask:
         # Reserved to implement the mask
-        GPU.masking(GPU.img1, GPU.img1, GPU.mask, local_size=None,
+        GPU.masking(GPU.img1, GPU.img1, GPU.mask, local_size = None,
                 global_size = grid.pixels)
-        GPU.masking(GPU.img2, GPU.img2, GPU.mask, local_size=None,
+        GPU.masking(GPU.img2, GPU.img2, GPU.mask, local_size = None,
                 global_size = grid.pixels)
 
-    # Obtain SubImage
-    GPU.Slice(GPU.subImg1_1, GPU.img1, GPU.box_origin_x_1, GPU.box_origin_y_1,
-            GPU.data1, local_size = None, global_size = N_pixels_1)
-    GPU.Slice(GPU.subImg1_2, GPU.img2, GPU.box_origin_x_1, GPU.box_origin_y_1,
-            GPU.data1, local_size = None, global_size = N_pixels_1)
+    # Apply gaussian blur only on first iteration if required
+    if Parameters.gaussian_filter:
+        GPU.gaussian_filter(GPU.img1_g, GPU.img1, GPU.kernel, GPU.data1,
+                local_size = None, global_size = grid.pixels)
+        GPU.gaussian_filter(GPU.img2_g, GPU.img2, GPU.kernel, GPU.data1,
+                local_size = None, global_size = grid.pixels)
+
+        # Obtain SubImage
+        GPU.Slice(GPU.subImg1_1, GPU.img1_g, GPU.box_origin_x_1, GPU.box_origin_y_1,
+                GPU.data1, local_size = None, global_size = N_pixels_1)
+        GPU.Slice(GPU.subImg1_2, GPU.img2_g, GPU.box_origin_x_1, GPU.box_origin_y_1,
+                GPU.data1, local_size = None, global_size = N_pixels_1)
+
+    else:
+        # Obtain SubImage
+        GPU.Slice(GPU.subImg1_1, GPU.img1, GPU.box_origin_x_1, GPU.box_origin_y_1,
+                GPU.data1, local_size = None, global_size = N_pixels_1)
+        GPU.Slice(GPU.subImg1_2, GPU.img2, GPU.box_origin_x_1, GPU.box_origin_y_1,
+                GPU.data1, local_size = None, global_size = N_pixels_1)
 
     for i in range(0,Parameters.no_iter_1):
         if i:
@@ -356,18 +490,18 @@ def processing(img1_name, img2_name, thr):
                         global_size = N_boxes_1)
 
             # Jacobian matrix
-            GPU.jacobian(GPU.temp_dx, GPU.temp_dy, GPU.u1_f, GPU.x1, GPU.y1,
+            GPU.jacobian(GPU.temp_dx_1, GPU.temp_dy_1, GPU.u1_f, GPU.x1, GPU.y1,
                     GPU.data1, local_size = None, global_size = N_boxes_1)
-            GPU.box_blur(GPU.du_dx_1, GPU.temp_dx, GPU.data1,
+            GPU.box_blur(GPU.du_dx_1, GPU.temp_dx_1, GPU.data1,
                     local_size = None, global_size = N_boxes_1)
-            GPU.box_blur(GPU.du_dy_1, GPU.temp_dy, GPU.data1,
+            GPU.box_blur(GPU.du_dy_1, GPU.temp_dy_1, GPU.data1,
                     local_size = None, global_size = N_boxes_1)
 
-            GPU.jacobian(GPU.temp_dx, GPU.temp_dy, GPU.v1_f, GPU.x1, GPU.y1,
+            GPU.jacobian(GPU.temp_dx_1, GPU.temp_dy_1, GPU.v1_f, GPU.x1, GPU.y1,
                     GPU.data1, local_size = None, global_size = N_boxes_1)
-            GPU.box_blur(GPU.dv_dx_1, GPU.temp_dx, GPU.data1,
+            GPU.box_blur(GPU.dv_dx_1, GPU.temp_dx_1, GPU.data1,
                     local_size = None, global_size = N_boxes_1)
-            GPU.box_blur(GPU.dv_dy_1, GPU.temp_dy, GPU.data1,
+            GPU.box_blur(GPU.dv_dy_1, GPU.temp_dy_1, GPU.data1,
                     local_size = None, global_size = N_boxes_1)
 
             # Deformed image
@@ -509,4 +643,4 @@ def processing(img1_name, img2_name, thr):
     GPU.img1 = thr.to_device(Img1)
     GPU.img2 = thr.to_device(Img2)
 
-    return 1
+    return 0
