@@ -17,10 +17,6 @@ def processing(Img1, Img2):
     if Parameters.mask:
         [Img1, Img2] = masking(Img1, Img2)
 
-    # Apply Gaussian filter to images
-    if Parameters.gaussian_filter:
-        [Img1, Img2] = Gaussian_Filter(Img1, Img2, Parameters.gaussian_filter)
-
     # Firs cross-correlation
     [x1, y1, u1, v1] = corrFFT1(Img1, Img2)
 
@@ -65,6 +61,10 @@ def corrFFT1(Img1, Img2):
         Weighting_Function = weight_function(i_matrix, j_matrix,
                 box_size_x, box_size_y)
 
+    # Apply Gaussian filter to images only for first iteration
+    if Parameters.gaussian_filter:
+        [Img1, Img2] = gaussian_filter(Img1, Img2, Parameters.gaussian_filter)
+
     for i in range(0, no_boxes_1_x):
         for j in range(0, no_boxes_1_y):
 
@@ -98,8 +98,8 @@ def corrFFT1(Img1, Img2):
             SubImg2 = SubImg2-sum(sum(SubImg2))/(box_size_y*box_size_x)
 
             # Sum of intensity Image to Scale at end
-            Sigma1 = max(0.1,np.sqrt(sum(sum(SubImg1**2))))
-            Sigma2 = max(0.1,np.sqrt(sum(sum(SubImg2**2))))
+            Sigma1 = max(0.1, np.sqrt(sum(sum(SubImg1**2))))
+            Sigma2 = max(0.1, np.sqrt(sum(sum(SubImg2**2))))
 
             # Cross Correlation Function of the pair images scaled with
             # sigma1 and sigma2
@@ -697,17 +697,23 @@ def median_filter(u,v,limit):
 
 def gaussian_filter(Image_1, Image_2, gaussian_size):
 
-    # Apply Gaussian filter to particles in the image
-    x = np.arange(0,2*np.ceil(2*gaussian_size).astype(int)+1)
-    x = np.exp(-(x-np.ceil(2*gaussian_size)-1)**2/gaussian_size**2)
-    B = np.multiply(np.transpose(x),x)
-    B = B/np.sum(np.sum(B))
+    B = gaussian_kernel(gaussian_size)
 
+    # Apply Gaussian filter to particles in the image
     Image_1 = cv2.filter2D(Image_1,-1,B,borderType=cv2.BORDER_CONSTANT)
     Image_2 = cv2.filter2D(Image_2,-1,B,borderType=cv2.BORDER_CONSTANT)
 
     return Image_1, Image_2
 
+def gaussian_kernel(gaussian_size):
+    x = np.arange(1,2*np.ceil(2*gaussian_size).astype(int)+2)
+    x = np.exp(-(x-np.ceil(2*gaussian_size)-1)**2/gaussian_size**2)
+    B = np.outer(np.transpose(x),x)
+    B = B/np.sum(np.sum(B))
+
+    return B
+
+
 def jacobian_matrix(u, v, x, y, no_box_x, no_box_y):
 
     # Initialize matrix
